@@ -1,3 +1,4 @@
+#include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -20,7 +21,7 @@
 
 char * Get_Word(FILE *fp, int *WordLength,int *eofptr)
 {
-  char c;
+  int c;
   int Available;
   int CharsRead;
   char *Word;
@@ -33,7 +34,8 @@ char * Get_Word(FILE *fp, int *WordLength,int *eofptr)
   *eofptr = 0;
   while(1){
     c=getc(fp);
-    if(isspace(c)){
+    //    if(isspace(c)) {
+    if ( (c == ' ') || (c == '\t') || (c == '\n') || (c == '\r') || (c == '\f') || (c == '\v')) {
       Word[CharsRead]='\0';
       *WordLength=CharsRead;
       return(Word);
@@ -47,8 +49,8 @@ char * Get_Word(FILE *fp, int *WordLength,int *eofptr)
     if(CharsRead == (Available-1)){ /* -1 because of null */
       Available += INITLENGTH/2;
       Word = (char *) realloc( (void *) Word, (size_t) (Available * sizeof (char)));
-      if(Word == (char *) 0) return(Word);
+      if(Word == NULL) return(Word);
     }
-    Word[CharsRead++]=c;
+    Word[CharsRead++]= (char) c;
   }
 }
