@@ -1,4 +1,4 @@
-/* Time-stamp: <2007-03-02 18:25:02 poser>
+/* Time-stamp: <2007-08-07 01:59:57 poser>
  *
  * Convert text containing various 7-bit ASCII escapes to UTF-7 Unicode.
  *
@@ -70,6 +70,7 @@ Free Software Foundation.\n");
   fprintf(stderr,"Report bugs to: billposer@alum.mit.edu.\n");
 }
 
+
 void
 ShowUsage(void){
   fprintf(stderr,_("This program is a filter which converts 7-bit ASCII text\n\
@@ -81,7 +82,6 @@ containing various representations for non-ASCII characters\nto UTF-8 Unicode.\n
   fprintf(stderr,_("       -p Input consists of pure escapes except for non-null whitespace.\n"));
   fprintf(stderr,_("       -q Quiet - don't chat.\n"));
   fprintf(stderr,_("       -v Print version information.\n"));
-  fprintf(stderr,_("       -8 Convert only tokens above the ASCII range.\n"));
   fprintf(stderr, 
 	  _("       -Z <format> Convert input using the supplied format.\n"));
   fprintf(stderr,_("Report bugs to: billposer@alum.mit.edu\n"));
@@ -158,6 +158,7 @@ static char *Formats [] = {
 "16#%04X",	/* PSPT */
 "#16r%04X",	/* CLR */
 "16#%04X#",	/* ADA */
+"&#%02X;",	/* HDML */
 "\\%03o\\%03o\\%03o",	/* BYTEO */
 "\\d%03d\\d%03d\\d%03d",	/* BYTED */
 "\\x%02x\\x%02x\\x%02x",	/* BYTEX */
@@ -284,7 +285,7 @@ int main (int ac, char *av[])
    }
 
    if(AllHTMLP && PureP) {
-     fprintf(stderr,_("Conversion of all three HTMl formats is not supported in pure mode.\n"));
+     fprintf(stderr,_("Conversion of all three HTML formats is not supported in pure mode.\n"));
      exit(BADOPTION);
    }
 
@@ -359,10 +360,10 @@ int main (int ac, char *av[])
        else {
 	 if (UTF8ValueP) putchar(num);
 	 else putu8(num);
-	 if( (FType == HTMLD) || (FType == HTMLX) || (FType == CHENT)) {
+	 if( (FType == HTMLD) || (FType == HTMLX) || (FType == CHENT) || (FType == HDML)) {
 	   if(*(str+NConsumed-1) != ';') {
 	     MicrosoftStyle++;
-	     fprintf(stderr,_("The HTML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),str,TokenNumber);
+	     fprintf(stderr,_("The HTML/HDML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),str,TokenNumber);
 	   }
 	 }
        }
@@ -377,8 +378,14 @@ int main (int ac, char *av[])
    while(fgets(lbuf,LBUFSIZE,stdin) != NULL) {
      LineNo++;
      last = strlen(lbuf) - 1;
-     if(lbuf[last] == '\n') {lbuf[last] = '\0'; last--;}
-     if(last < 0) continue;
+     if(lbuf[last] == '\n') {
+       lbuf[last] = '\0';
+       last--;
+     }
+     if(last < 0) {
+       putchar('\n');
+       continue;
+     }
      iptr = lbuf;
      if(FType == JFMT) {
        while(*iptr) {
@@ -452,7 +459,7 @@ int main (int ac, char *av[])
 	     iptr+=NConsumed;
 	     if(*(iptr-1) != ';') {
 	       MicrosoftStyle++;
-	       fprintf(stderr,_("The HTML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),ExtractSubstring(tmpstr,iptr-NConsumed,iptr-1),TokenNumber);
+	       fprintf(stderr,_("The HTML/HDML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),ExtractSubstring(tmpstr,iptr-NConsumed,iptr-1),TokenNumber);
 	     }
 	     TokenNumber++;
 	     continue;
@@ -462,7 +469,7 @@ int main (int ac, char *av[])
 	     iptr+=NConsumed;
 	     if(*(iptr-1) != ';') {
 	       MicrosoftStyle++;
-	       fprintf(stderr,_("The HTML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),ExtractSubstring(tmpstr,iptr-NConsumed,iptr-1),TokenNumber);
+	       fprintf(stderr,_("The HTML/HDML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),ExtractSubstring(tmpstr,iptr-NConsumed,iptr-1),TokenNumber);
 	     }
 	     TokenNumber++;
 	     continue;
@@ -474,12 +481,12 @@ int main (int ac, char *av[])
 	     iptr+=NConsumed;
 	     if(*(iptr-1) != ';') {
 	       MicrosoftStyle++;
-	       fprintf(stderr,_("The HTML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),ExtractSubstring(tmpstr,iptr-NConsumed,iptr-1),TokenNumber);
+	       fprintf(stderr,_("The HTML/HDML entity %1$s at token %2$lu lacks the requisite final semicolon.\n"),ExtractSubstring(tmpstr,iptr-NConsumed,iptr-1),TokenNumber);
 	     }
 	     TokenNumber++;
 	   }
 	   else {
-	     fprintf(stderr,"ascii2uni: unknown HTML character entity \"&%s;\" at line %d\n",
+	     fprintf(stderr,"ascii2uni: unknown HTML/HDML character entity \"&%s;\" at line %d\n",
 		     enam,LineNo);
 	     putu8(UNI_REPLACEMENT_CHAR);
 	     iptr+=NConsumed;
@@ -514,6 +521,9 @@ int main (int ac, char *av[])
 	   }
 	   TokenNumber++;
        }
+       else if (HDML == FType) {
+	 /* Check for HDML character entities */
+       }
        else {			/* Default - not BMPSplitP, Q, or byte format */
 	 //	 NConsumed=0;
 	 if(sscanf(iptr,afmt,&num,&NConsumed)) {
