@@ -1,4 +1,4 @@
-/* Time-stamp: <2007-03-11 20:50:40 poser>
+/* Time-stamp: <2007-08-07 00:54:51 poser>
  *
  * Converts UTF-8 Unicode to pure 7-bit ASCII using any of a number
  * of different representations. 
@@ -206,6 +206,8 @@ static char *Formats [] = {
   "#16r%04X",
   "16#%04x#",	/* ADA */
   "16#%04X#",
+  "&#%02x;",  /* HDML */
+  "&#%02X;",
   "\\%03hho\\%03hho\\%03hho",	/* BYTEO */
   "\\%03hho\\%03hho\\%03hho",
   "\\d%03hhd\\d%03hhd\\d%03hhd",	/* BYTED */
@@ -2601,6 +2603,7 @@ int main (int ac, char *av[])
   extern void ListFormatArguments(short);
   extern void SetFormat(char *, int *, short *,int *, short *, short *);
 
+
   opterr = 0;
   ByteCnt = 0L;
   CharCnt = 0L;
@@ -2702,8 +2705,8 @@ int main (int ac, char *av[])
 
   /* Combinatorial checks */
 
-  if(UseEntitiesP && !(FType == HTMLX || FType == HTMLD)) {
-    fprintf(stderr,"Use of character entities must be combined with either\ndecimal or hexadecimal HTML character references.\n");
+  if(UseEntitiesP && !(FType == HTMLX || FType == HTMLD || FType == HDML)) {
+    fprintf(stderr,"Use of character entities must be combined with either\ndecimal or hexadecimal HTML character references or HDML hexadecimal character references.\n");
     exit(BADOPTION);
   }
 
@@ -2871,6 +2874,13 @@ int main (int ac, char *av[])
 	continue;
       }
     } 
+    if ( (FType == HDML) && (c > 0xFF)) {
+      fprintf(stderr,"Character 0x%04x encountered at character %d skipped.\n"
+	      ,c,CharCnt);
+      fprintf(stderr,"   Characters above 0xFF cannot be represented in HDML.\n");
+      DeletedCnt++;
+      continue;
+    }
     switch (c) {
     case 0x000A:
       if(PreserveNewlinesP) putchar((int)c);
@@ -2909,8 +2919,14 @@ int main (int ac, char *av[])
 	}
 	else {
 	  if (UseEntitiesP) {
-	    if ( (e=LookupEntityForCode(c)) != NULL) printf("&%s;",e);
-	    else printf(fmt,c);
+	    if (FType == HDML) {
+	      if ((e=LookupHDMLEntityForCode(c)) != NULL) printf("&%s;",e);
+	      else printf(fmt,c);
+	    }
+	    else {
+	      if ((e=LookupEntityForCode(c)) != NULL) printf("&%s;",e);
+	      else printf(fmt,c);
+	    }
 	    ConvertedCnt++;
 	  }
 	  else {
